[gimp] Rename GIMP_TYPE_INT8_ARRAY to GIMP_TYPE_UINT8_ARRAY



commit 652fd75891cfb3d7308bf1adf9e8a12738b2b404
Author: Michael Natterer <mitch gimp org>
Date:   Thu Aug 15 15:04:34 2019 +0200

    Rename GIMP_TYPE_INT8_ARRAY to GIMP_TYPE_UINT8_ARRAY
    
    and GimpParamSpecInt8Array to GimpParamSpecUInt8Array

 app/core/gimp-memsize.c                          |  2 +-
 app/pdb/brush-cmds.c                             | 20 +++----
 app/pdb/drawable-cmds.c                          | 40 ++++++-------
 app/pdb/fileops-cmds.c                           | 10 ++--
 app/pdb/gimp-pdb-compat.c                        |  2 +-
 app/pdb/image-cmds.c                             | 30 +++++-----
 app/pdb/image-color-profile-cmds.c               | 40 ++++++-------
 app/pdb/image-convert-cmds.c                     | 10 ++--
 app/pdb/pattern-cmds.c                           | 10 ++--
 app/pdb/pdb-cmds.c                               | 20 +++----
 app/pdb/plug-in-cmds.c                           | 10 ++--
 app/plug-in/gimpgpparams.c                       |  4 +-
 app/plug-in/gimpplugin-message.c                 |  2 +-
 app/widgets/gimpbrushselect.c                    | 18 +++---
 app/widgets/gimppatternselect.c                  | 14 ++---
 devel-docs/libgimpbase/libgimpbase3-sections.txt | 28 ++++-----
 devel-docs/libgimpbase/libgimpbase3.types        |  4 +-
 libgimp/gimp.c                                   |  2 +-
 libgimp/gimpbrush_pdb.c                          |  4 +-
 libgimp/gimpbrushselect.c                        | 12 ++--
 libgimp/gimpdrawable_pdb.c                       | 10 ++--
 libgimp/gimpgpcompat.c                           | 24 ++++----
 libgimp/gimpgpparams-body.c                      | 20 +++----
 libgimp/gimpgpparams.c                           |  4 +-
 libgimp/gimpimage_pdb.c                          |  8 +--
 libgimp/gimpimagecolorprofile_pdb.c              | 12 ++--
 libgimp/gimpimageconvert_pdb.c                   |  4 +-
 libgimp/gimppattern_pdb.c                        |  2 +-
 libgimp/gimppatternselect.c                      | 12 ++--
 libgimp/gimppdb_pdb.c                            |  6 +-
 libgimp/gimpplugin_pdb.c                         |  4 +-
 libgimpbase/gimpbase.def                         | 18 +++---
 libgimpbase/gimpparamspecs.c                     | 76 ++++++++++++------------
 libgimpbase/gimpparamspecs.h                     | 56 ++++++++---------
 pdb/app.pl                                       |  8 +--
 pdb/pdb.pl                                       | 10 ++--
 plug-ins/common/colormap-remap.c                 | 14 ++---
 plug-ins/common/file-gih.c                       | 20 +++----
 plug-ins/script-fu/scheme-wrapper.c              |  8 +--
 39 files changed, 299 insertions(+), 299 deletions(-)
---
diff --git a/app/core/gimp-memsize.c b/app/core/gimp-memsize.c
index a134dec175..7c55c7b0d0 100644
--- a/app/core/gimp-memsize.c
+++ b/app/core/gimp-memsize.c
@@ -220,7 +220,7 @@ gimp_g_value_get_memsize (GValue *value)
                                                 NULL);
         }
       else if (GIMP_VALUE_HOLDS_ARRAY (value)       ||
-               GIMP_VALUE_HOLDS_INT8_ARRAY (value)  ||
+               GIMP_VALUE_HOLDS_UINT8_ARRAY (value) ||
                GIMP_VALUE_HOLDS_INT16_ARRAY (value) ||
                GIMP_VALUE_HOLDS_INT32_ARRAY (value) ||
                GIMP_VALUE_HOLDS_FLOAT_ARRAY (value))
diff --git a/app/pdb/brush-cmds.c b/app/pdb/brush-cmds.c
index 271e7dfcfc..29de5b653d 100644
--- a/app/pdb/brush-cmds.c
+++ b/app/pdb/brush-cmds.c
@@ -393,10 +393,10 @@ brush_get_pixels_invoker (GimpProcedure         *procedure,
       g_value_set_int (gimp_value_array_index (return_vals, 2), height);
       g_value_set_int (gimp_value_array_index (return_vals, 3), mask_bpp);
       g_value_set_int (gimp_value_array_index (return_vals, 4), num_mask_bytes);
-      gimp_value_take_int8_array (gimp_value_array_index (return_vals, 5), mask_bytes, num_mask_bytes);
+      gimp_value_take_uint8_array (gimp_value_array_index (return_vals, 5), mask_bytes, num_mask_bytes);
       g_value_set_int (gimp_value_array_index (return_vals, 6), color_bpp);
       g_value_set_int (gimp_value_array_index (return_vals, 7), num_color_bytes);
-      gimp_value_take_int8_array (gimp_value_array_index (return_vals, 8), color_bytes, num_color_bytes);
+      gimp_value_take_uint8_array (gimp_value_array_index (return_vals, 8), color_bytes, num_color_bytes);
     }
 
   return return_vals;
@@ -1192,10 +1192,10 @@ register_brush_procs (GimpPDB *pdb)
                                                      0, G_MAXINT32, 0,
                                                      GIMP_PARAM_READWRITE));
   gimp_procedure_add_return_value (procedure,
-                                   gimp_param_spec_int8_array ("mask-bytes",
-                                                               "mask bytes",
-                                                               "The brush mask data",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("mask-bytes",
+                                                                "mask bytes",
+                                                                "The brush mask data",
+                                                                GIMP_PARAM_READWRITE));
   gimp_procedure_add_return_value (procedure,
                                    g_param_spec_int ("color-bpp",
                                                      "color bpp",
@@ -1209,10 +1209,10 @@ register_brush_procs (GimpPDB *pdb)
                                                      0, G_MAXINT32, 0,
                                                      GIMP_PARAM_READWRITE));
   gimp_procedure_add_return_value (procedure,
-                                   gimp_param_spec_int8_array ("color-bytes",
-                                                               "color bytes",
-                                                               "The brush color data",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("color-bytes",
+                                                                "color bytes",
+                                                                "The brush color data",
+                                                                GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
diff --git a/app/pdb/drawable-cmds.c b/app/pdb/drawable-cmds.c
index 83876bf2d7..149f7554a0 100644
--- a/app/pdb/drawable-cmds.c
+++ b/app/pdb/drawable-cmds.c
@@ -636,7 +636,7 @@ drawable_get_pixel_invoker (GimpProcedure         *procedure,
   if (success)
     {
       g_value_set_int (gimp_value_array_index (return_vals, 1), num_channels);
-      gimp_value_take_int8_array (gimp_value_array_index (return_vals, 2), pixel, num_channels);
+      gimp_value_take_uint8_array (gimp_value_array_index (return_vals, 2), pixel, num_channels);
     }
 
   return return_vals;
@@ -661,7 +661,7 @@ drawable_set_pixel_invoker (GimpProcedure         *procedure,
   x_coord = g_value_get_int (gimp_value_array_index (args, 1));
   y_coord = g_value_get_int (gimp_value_array_index (args, 2));
   num_channels = g_value_get_int (gimp_value_array_index (args, 3));
-  pixel = gimp_value_get_int8_array (gimp_value_array_index (args, 4));
+  pixel = gimp_value_get_uint8_array (gimp_value_array_index (args, 4));
 
   if (success)
     {
@@ -825,7 +825,7 @@ drawable_thumbnail_invoker (GimpProcedure         *procedure,
       g_value_set_int (gimp_value_array_index (return_vals, 2), actual_height);
       g_value_set_int (gimp_value_array_index (return_vals, 3), bpp);
       g_value_set_int (gimp_value_array_index (return_vals, 4), thumbnail_data_count);
-      gimp_value_take_int8_array (gimp_value_array_index (return_vals, 5), thumbnail_data, 
thumbnail_data_count);
+      gimp_value_take_uint8_array (gimp_value_array_index (return_vals, 5), thumbnail_data, 
thumbnail_data_count);
     }
 
   return return_vals;
@@ -907,7 +907,7 @@ drawable_sub_thumbnail_invoker (GimpProcedure         *procedure,
       g_value_set_int (gimp_value_array_index (return_vals, 2), height);
       g_value_set_int (gimp_value_array_index (return_vals, 3), bpp);
       g_value_set_int (gimp_value_array_index (return_vals, 4), thumbnail_data_count);
-      gimp_value_take_int8_array (gimp_value_array_index (return_vals, 5), thumbnail_data, 
thumbnail_data_count);
+      gimp_value_take_uint8_array (gimp_value_array_index (return_vals, 5), thumbnail_data, 
thumbnail_data_count);
     }
 
   return return_vals;
@@ -1584,10 +1584,10 @@ register_drawable_procs (GimpPDB *pdb)
                                                      0, G_MAXINT32, 0,
                                                      GIMP_PARAM_READWRITE | GIMP_PARAM_NO_VALIDATE));
   gimp_procedure_add_return_value (procedure,
-                                   gimp_param_spec_int8_array ("pixel",
-                                                               "pixel",
-                                                               "The pixel value",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("pixel",
+                                                                "pixel",
+                                                                "The pixel value",
+                                                                GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
@@ -1630,10 +1630,10 @@ register_drawable_procs (GimpPDB *pdb)
                                                  0, G_MAXINT32, 0,
                                                  GIMP_PARAM_READWRITE | GIMP_PARAM_NO_VALIDATE));
   gimp_procedure_add_argument (procedure,
-                               gimp_param_spec_int8_array ("pixel",
-                                                           "pixel",
-                                                           "The pixel value",
-                                                           GIMP_PARAM_READWRITE));
+                               gimp_param_spec_uint8_array ("pixel",
+                                                            "pixel",
+                                                            "The pixel value",
+                                                            GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
@@ -1773,10 +1773,10 @@ register_drawable_procs (GimpPDB *pdb)
                                                      0, G_MAXINT32, 0,
                                                      GIMP_PARAM_READWRITE));
   gimp_procedure_add_return_value (procedure,
-                                   gimp_param_spec_int8_array ("thumbnail-data",
-                                                               "thumbnail data",
-                                                               "The thumbnail data",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("thumbnail-data",
+                                                                "thumbnail data",
+                                                                "The thumbnail data",
+                                                                GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
@@ -1861,10 +1861,10 @@ register_drawable_procs (GimpPDB *pdb)
                                                      0, G_MAXINT32, 0,
                                                      GIMP_PARAM_READWRITE));
   gimp_procedure_add_return_value (procedure,
-                                   gimp_param_spec_int8_array ("thumbnail-data",
-                                                               "thumbnail data",
-                                                               "The thumbnail data",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("thumbnail-data",
+                                                                "thumbnail data",
+                                                                "The thumbnail data",
+                                                                GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
diff --git a/app/pdb/fileops-cmds.c b/app/pdb/fileops-cmds.c
index 5badefda6f..6c10dc113a 100644
--- a/app/pdb/fileops-cmds.c
+++ b/app/pdb/fileops-cmds.c
@@ -377,7 +377,7 @@ file_load_thumbnail_invoker (GimpProcedure         *procedure,
       g_value_set_int (gimp_value_array_index (return_vals, 1), width);
       g_value_set_int (gimp_value_array_index (return_vals, 2), height);
       g_value_set_int (gimp_value_array_index (return_vals, 3), thumb_data_count);
-      gimp_value_take_int8_array (gimp_value_array_index (return_vals, 4), thumb_data, thumb_data_count);
+      gimp_value_take_uint8_array (gimp_value_array_index (return_vals, 4), thumb_data, thumb_data_count);
     }
 
   return return_vals;
@@ -884,10 +884,10 @@ register_fileops_procs (GimpPDB *pdb)
                                                      0, G_MAXINT32, 0,
                                                      GIMP_PARAM_READWRITE));
   gimp_procedure_add_return_value (procedure,
-                                   gimp_param_spec_int8_array ("thumb-data",
-                                                               "thumb data",
-                                                               "The thumbnail data",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("thumb-data",
+                                                                "thumb data",
+                                                                "The thumbnail data",
+                                                                GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
diff --git a/app/pdb/gimp-pdb-compat.c b/app/pdb/gimp-pdb-compat.c
index b1f454f63a..e26ef1e648 100644
--- a/app/pdb/gimp-pdb-compat.c
+++ b/app/pdb/gimp-pdb-compat.c
@@ -64,7 +64,7 @@ gimp_pdb_compat_arg_type_from_gtype (GType type)
 
         { GIMP_TYPE_INT32_ARRAY,     GIMP_PDB_INT32ARRAY  },
         { GIMP_TYPE_INT16_ARRAY,     GIMP_PDB_INT16ARRAY  },
-        { GIMP_TYPE_INT8_ARRAY,      GIMP_PDB_INT8ARRAY   },
+        { GIMP_TYPE_UINT8_ARRAY,     GIMP_PDB_INT8ARRAY   },
         { GIMP_TYPE_FLOAT_ARRAY,     GIMP_PDB_FLOATARRAY  },
         { GIMP_TYPE_STRING_ARRAY,    GIMP_PDB_STRINGARRAY },
         { GIMP_TYPE_RGB_ARRAY,       GIMP_PDB_COLORARRAY  },
diff --git a/app/pdb/image-cmds.c b/app/pdb/image-cmds.c
index ed611bca7e..13ee46a3ab 100644
--- a/app/pdb/image-cmds.c
+++ b/app/pdb/image-cmds.c
@@ -1481,7 +1481,7 @@ image_get_colormap_invoker (GimpProcedure         *procedure,
   if (success)
     {
       g_value_set_int (gimp_value_array_index (return_vals, 1), num_bytes);
-      gimp_value_take_int8_array (gimp_value_array_index (return_vals, 2), colormap, num_bytes);
+      gimp_value_take_uint8_array (gimp_value_array_index (return_vals, 2), colormap, num_bytes);
     }
 
   return return_vals;
@@ -1502,7 +1502,7 @@ image_set_colormap_invoker (GimpProcedure         *procedure,
 
   image = gimp_value_get_image (gimp_value_array_index (args, 0), gimp);
   num_bytes = g_value_get_int (gimp_value_array_index (args, 1));
-  colormap = gimp_value_get_int8_array (gimp_value_array_index (args, 2));
+  colormap = gimp_value_get_uint8_array (gimp_value_array_index (args, 2));
 
   if (success)
     {
@@ -1693,7 +1693,7 @@ image_thumbnail_invoker (GimpProcedure         *procedure,
       g_value_set_int (gimp_value_array_index (return_vals, 2), actual_height);
       g_value_set_int (gimp_value_array_index (return_vals, 3), bpp);
       g_value_set_int (gimp_value_array_index (return_vals, 4), thumbnail_data_count);
-      gimp_value_take_int8_array (gimp_value_array_index (return_vals, 5), thumbnail_data, 
thumbnail_data_count);
+      gimp_value_take_uint8_array (gimp_value_array_index (return_vals, 5), thumbnail_data, 
thumbnail_data_count);
     }
 
   return return_vals;
@@ -4122,10 +4122,10 @@ register_image_procs (GimpPDB *pdb)
                                                      0, G_MAXINT32, 0,
                                                      GIMP_PARAM_READWRITE));
   gimp_procedure_add_return_value (procedure,
-                                   gimp_param_spec_int8_array ("colormap",
-                                                               "colormap",
-                                                               "The image's colormap.",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("colormap",
+                                                                "colormap",
+                                                                "The image's colormap.",
+                                                                GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
@@ -4156,10 +4156,10 @@ register_image_procs (GimpPDB *pdb)
                                                  0, 768, 0,
                                                  GIMP_PARAM_READWRITE));
   gimp_procedure_add_argument (procedure,
-                               gimp_param_spec_int8_array ("colormap",
-                                                           "colormap",
-                                                           "The new colormap values",
-                                                           GIMP_PARAM_READWRITE));
+                               gimp_param_spec_uint8_array ("colormap",
+                                                            "colormap",
+                                                            "The new colormap values",
+                                                            GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
@@ -4332,10 +4332,10 @@ register_image_procs (GimpPDB *pdb)
                                                      0, G_MAXINT32, 0,
                                                      GIMP_PARAM_READWRITE));
   gimp_procedure_add_return_value (procedure,
-                                   gimp_param_spec_int8_array ("thumbnail-data",
-                                                               "thumbnail data",
-                                                               "The thumbnail data",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("thumbnail-data",
+                                                                "thumbnail data",
+                                                                "The thumbnail data",
+                                                                GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
diff --git a/app/pdb/image-color-profile-cmds.c b/app/pdb/image-color-profile-cmds.c
index 6ef5b801f6..1c53d3d3df 100644
--- a/app/pdb/image-color-profile-cmds.c
+++ b/app/pdb/image-color-profile-cmds.c
@@ -82,7 +82,7 @@ image_get_color_profile_invoker (GimpProcedure         *procedure,
   if (success)
     {
       g_value_set_int (gimp_value_array_index (return_vals, 1), num_bytes);
-      gimp_value_take_int8_array (gimp_value_array_index (return_vals, 2), profile_data, num_bytes);
+      gimp_value_take_uint8_array (gimp_value_array_index (return_vals, 2), profile_data, num_bytes);
     }
 
   return return_vals;
@@ -128,7 +128,7 @@ image_get_effective_color_profile_invoker (GimpProcedure         *procedure,
   if (success)
     {
       g_value_set_int (gimp_value_array_index (return_vals, 1), num_bytes);
-      gimp_value_take_int8_array (gimp_value_array_index (return_vals, 2), profile_data, num_bytes);
+      gimp_value_take_uint8_array (gimp_value_array_index (return_vals, 2), profile_data, num_bytes);
     }
 
   return return_vals;
@@ -149,7 +149,7 @@ image_set_color_profile_invoker (GimpProcedure         *procedure,
 
   image = gimp_value_get_image (gimp_value_array_index (args, 0), gimp);
   num_bytes = g_value_get_int (gimp_value_array_index (args, 1));
-  color_profile = gimp_value_get_int8_array (gimp_value_array_index (args, 2));
+  color_profile = gimp_value_get_uint8_array (gimp_value_array_index (args, 2));
 
   if (success)
     {
@@ -244,7 +244,7 @@ image_convert_color_profile_invoker (GimpProcedure         *procedure,
 
   image = gimp_value_get_image (gimp_value_array_index (args, 0), gimp);
   num_bytes = g_value_get_int (gimp_value_array_index (args, 1));
-  color_profile = gimp_value_get_int8_array (gimp_value_array_index (args, 2));
+  color_profile = gimp_value_get_uint8_array (gimp_value_array_index (args, 2));
   intent = g_value_get_enum (gimp_value_array_index (args, 3));
   bpc = g_value_get_boolean (gimp_value_array_index (args, 4));
 
@@ -356,10 +356,10 @@ register_image_color_profile_procs (GimpPDB *pdb)
                                                      0, G_MAXINT32, 0,
                                                      GIMP_PARAM_READWRITE));
   gimp_procedure_add_return_value (procedure,
-                                   gimp_param_spec_int8_array ("profile-data",
-                                                               "profile data",
-                                                               "The image's serialized color profile.",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("profile-data",
+                                                                "profile data",
+                                                                "The image's serialized color profile.",
+                                                                GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
@@ -390,10 +390,10 @@ register_image_color_profile_procs (GimpPDB *pdb)
                                                      0, G_MAXINT32, 0,
                                                      GIMP_PARAM_READWRITE));
   gimp_procedure_add_return_value (procedure,
-                                   gimp_param_spec_int8_array ("profile-data",
-                                                               "profile data",
-                                                               "The image's serialized color profile.",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("profile-data",
+                                                                "profile data",
+                                                                "The image's serialized color profile.",
+                                                                GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
@@ -424,10 +424,10 @@ register_image_color_profile_procs (GimpPDB *pdb)
                                                  0, G_MAXINT32, 0,
                                                  GIMP_PARAM_READWRITE));
   gimp_procedure_add_argument (procedure,
-                               gimp_param_spec_int8_array ("color-profile",
-                                                           "color profile",
-                                                           "The new serialized color profile",
-                                                           GIMP_PARAM_READWRITE));
+                               gimp_param_spec_uint8_array ("color-profile",
+                                                            "color profile",
+                                                            "The new serialized color profile",
+                                                            GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
@@ -488,10 +488,10 @@ register_image_color_profile_procs (GimpPDB *pdb)
                                                  0, G_MAXINT32, 0,
                                                  GIMP_PARAM_READWRITE));
   gimp_procedure_add_argument (procedure,
-                               gimp_param_spec_int8_array ("color-profile",
-                                                           "color profile",
-                                                           "The serialized color profile",
-                                                           GIMP_PARAM_READWRITE));
+                               gimp_param_spec_uint8_array ("color-profile",
+                                                            "color profile",
+                                                            "The serialized color profile",
+                                                            GIMP_PARAM_READWRITE));
   gimp_procedure_add_argument (procedure,
                                g_param_spec_enum ("intent",
                                                   "intent",
diff --git a/app/pdb/image-convert-cmds.c b/app/pdb/image-convert-cmds.c
index d708330581..4f679b2b08 100644
--- a/app/pdb/image-convert-cmds.c
+++ b/app/pdb/image-convert-cmds.c
@@ -202,7 +202,7 @@ image_convert_set_dither_matrix_invoker (GimpProcedure         *procedure,
   width = g_value_get_int (gimp_value_array_index (args, 0));
   height = g_value_get_int (gimp_value_array_index (args, 1));
   matrix_length = g_value_get_int (gimp_value_array_index (args, 2));
-  matrix = gimp_value_get_int8_array (gimp_value_array_index (args, 3));
+  matrix = gimp_value_get_uint8_array (gimp_value_array_index (args, 3));
 
   if (success)
     {
@@ -406,10 +406,10 @@ register_image_convert_procs (GimpPDB *pdb)
                                                  1, 1024, 1,
                                                  GIMP_PARAM_READWRITE));
   gimp_procedure_add_argument (procedure,
-                               gimp_param_spec_int8_array ("matrix",
-                                                           "matrix",
-                                                           "The matrix -- all values must be >= 1",
-                                                           GIMP_PARAM_READWRITE));
+                               gimp_param_spec_uint8_array ("matrix",
+                                                            "matrix",
+                                                            "The matrix -- all values must be >= 1",
+                                                            GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
diff --git a/app/pdb/pattern-cmds.c b/app/pdb/pattern-cmds.c
index f5c94ddd6d..8713faa2ec 100644
--- a/app/pdb/pattern-cmds.c
+++ b/app/pdb/pattern-cmds.c
@@ -144,7 +144,7 @@ pattern_get_pixels_invoker (GimpProcedure         *procedure,
       g_value_set_int (gimp_value_array_index (return_vals, 2), height);
       g_value_set_int (gimp_value_array_index (return_vals, 3), bpp);
       g_value_set_int (gimp_value_array_index (return_vals, 4), num_color_bytes);
-      gimp_value_take_int8_array (gimp_value_array_index (return_vals, 5), color_bytes, num_color_bytes);
+      gimp_value_take_uint8_array (gimp_value_array_index (return_vals, 5), color_bytes, num_color_bytes);
     }
 
   return return_vals;
@@ -243,10 +243,10 @@ register_pattern_procs (GimpPDB *pdb)
                                                      0, G_MAXINT32, 0,
                                                      GIMP_PARAM_READWRITE));
   gimp_procedure_add_return_value (procedure,
-                                   gimp_param_spec_int8_array ("color-bytes",
-                                                               "color bytes",
-                                                               "The pattern data.",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("color-bytes",
+                                                                "color bytes",
+                                                                "The pattern data.",
+                                                                GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 }
diff --git a/app/pdb/pdb-cmds.c b/app/pdb/pdb-cmds.c
index 27281ff11e..9e47e648ce 100644
--- a/app/pdb/pdb-cmds.c
+++ b/app/pdb/pdb-cmds.c
@@ -388,7 +388,7 @@ pdb_get_data_invoker (GimpProcedure         *procedure,
   if (success)
     {
       g_value_set_int (gimp_value_array_index (return_vals, 1), bytes);
-      gimp_value_take_int8_array (gimp_value_array_index (return_vals, 2), data, bytes);
+      gimp_value_take_uint8_array (gimp_value_array_index (return_vals, 2), data, bytes);
     }
 
   return return_vals;
@@ -444,7 +444,7 @@ pdb_set_data_invoker (GimpProcedure         *procedure,
 
   identifier = g_value_get_string (gimp_value_array_index (args, 0));
   bytes = g_value_get_int (gimp_value_array_index (args, 1));
-  data = gimp_value_get_int8_array (gimp_value_array_index (args, 2));
+  data = gimp_value_get_uint8_array (gimp_value_array_index (args, 2));
 
   if (success)
     {
@@ -798,10 +798,10 @@ register_pdb_procs (GimpPDB *pdb)
                                                      1, G_MAXINT32, 1,
                                                      GIMP_PARAM_READWRITE));
   gimp_procedure_add_return_value (procedure,
-                                   gimp_param_spec_int8_array ("data",
-                                                               "data",
-                                                               "A byte array containing data",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("data",
+                                                                "data",
+                                                                "A byte array containing data",
+                                                                GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
@@ -863,10 +863,10 @@ register_pdb_procs (GimpPDB *pdb)
                                                  1, G_MAXINT32, 1,
                                                  GIMP_PARAM_READWRITE));
   gimp_procedure_add_argument (procedure,
-                               gimp_param_spec_int8_array ("data",
-                                                           "data",
-                                                           "A byte array containing data",
-                                                           GIMP_PARAM_READWRITE));
+                               gimp_param_spec_uint8_array ("data",
+                                                            "data",
+                                                            "A byte array containing data",
+                                                            GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 }
diff --git a/app/pdb/plug-in-cmds.c b/app/pdb/plug-in-cmds.c
index 994169ae58..199a6c177f 100644
--- a/app/pdb/plug-in-cmds.c
+++ b/app/pdb/plug-in-cmds.c
@@ -247,7 +247,7 @@ plugin_icon_register_invoker (GimpProcedure         *procedure,
   procedure_name = g_value_get_string (gimp_value_array_index (args, 0));
   icon_type = g_value_get_enum (gimp_value_array_index (args, 1));
   icon_data_length = g_value_get_int (gimp_value_array_index (args, 2));
-  icon_data = gimp_value_get_int8_array (gimp_value_array_index (args, 3));
+  icon_data = gimp_value_get_uint8_array (gimp_value_array_index (args, 3));
 
   if (success)
     {
@@ -598,10 +598,10 @@ register_plug_in_procs (GimpPDB *pdb)
                                                  1, G_MAXINT32, 1,
                                                  GIMP_PARAM_READWRITE));
   gimp_procedure_add_argument (procedure,
-                               gimp_param_spec_int8_array ("icon-data",
-                                                           "icon data",
-                                                           "The procedure's icon. The format depends on the 
'icon_type' parameter",
-                                                           GIMP_PARAM_READWRITE));
+                               gimp_param_spec_uint8_array ("icon-data",
+                                                            "icon data",
+                                                            "The procedure's icon. The format depends on the 
'icon_type' parameter",
+                                                            GIMP_PARAM_READWRITE));
   gimp_pdb_register_procedure (pdb, procedure);
   g_object_unref (procedure);
 
diff --git a/app/plug-in/gimpgpparams.c b/app/plug-in/gimpgpparams.c
index deda7238b7..5a8c738b38 100644
--- a/app/plug-in/gimpgpparams.c
+++ b/app/plug-in/gimpgpparams.c
@@ -66,8 +66,8 @@ _gimp_gp_param_def_to_param_spec (gpointer          gimp,
       if (! strcmp (param_def->type_name, "GimpParamInt16Array"))
         return gimp_param_spec_int16_array (name, nick, blurb, flags);
 
-      if (! strcmp (param_def->type_name, "GimpParamInt8Array"))
-        return gimp_param_spec_int8_array (name, nick, blurb, flags);
+      if (! strcmp (param_def->type_name, "GimpParamUInt8Array"))
+        return gimp_param_spec_uint8_array (name, nick, blurb, flags);
 
       if (! strcmp (param_def->type_name, "GimpParamFloatArray"))
         return gimp_param_spec_float_array (name, nick, blurb, flags);
diff --git a/app/plug-in/gimpplugin-message.c b/app/plug-in/gimpplugin-message.c
index 9fa5ddd668..6aecb72d84 100644
--- a/app/plug-in/gimpplugin-message.c
+++ b/app/plug-in/gimpplugin-message.c
@@ -720,7 +720,7 @@ gimp_plug_in_handle_proc_install (GimpPlugIn    *plug_in,
 
       if ((! strcmp (param_def->type_name, "GimpParamInt32Array")     ||
            ! strcmp (param_def->type_name, "GimpParamInt16Array")     ||
-           ! strcmp (param_def->type_name, "GimpParamInt8Array")      ||
+           ! strcmp (param_def->type_name, "GimpParamUInt8Array")     ||
            ! strcmp (param_def->type_name, "GimpParamIntFloatArray")  ||
            ! strcmp (param_def->type_name, "GimpParamIntStringArray") ||
            ! strcmp (param_def->type_name, "GimpParamIntColorArray"))
diff --git a/app/widgets/gimpbrushselect.c b/app/widgets/gimpbrushselect.c
index 4fdf5682ee..e422341a1a 100644
--- a/app/widgets/gimpbrushselect.c
+++ b/app/widgets/gimpbrushselect.c
@@ -280,15 +280,15 @@ gimp_brush_select_run_callback (GimpPdbDialog  *dialog,
                                         dialog->caller_context,
                                         NULL, error,
                                         dialog->callback_name,
-                                        G_TYPE_STRING,        gimp_object_get_name (object),
-                                        G_TYPE_DOUBLE,        gimp_context_get_opacity (dialog->context) * 
100.0,
-                                        G_TYPE_INT,           GIMP_BRUSH_SELECT (dialog)->spacing,
-                                        GIMP_TYPE_LAYER_MODE, gimp_context_get_paint_mode (dialog->context),
-                                        G_TYPE_INT,           gimp_brush_get_width  (brush),
-                                        G_TYPE_INT,           gimp_brush_get_height (brush),
-                                        G_TYPE_INT,           array->length,
-                                        GIMP_TYPE_INT8_ARRAY, array,
-                                        G_TYPE_BOOLEAN,       closing,
+                                        G_TYPE_STRING,         gimp_object_get_name (object),
+                                        G_TYPE_DOUBLE,         gimp_context_get_opacity (dialog->context) * 
100.0,
+                                        G_TYPE_INT,            GIMP_BRUSH_SELECT (dialog)->spacing,
+                                        GIMP_TYPE_LAYER_MODE,  gimp_context_get_paint_mode (dialog->context),
+                                        G_TYPE_INT,            gimp_brush_get_width  (brush),
+                                        G_TYPE_INT,            gimp_brush_get_height (brush),
+                                        G_TYPE_INT,            array->length,
+                                        GIMP_TYPE_UINT8_ARRAY, array,
+                                        G_TYPE_BOOLEAN,        closing,
                                         G_TYPE_NONE);
 
   gimp_array_free (array);
diff --git a/app/widgets/gimppatternselect.c b/app/widgets/gimppatternselect.c
index 135caa8d3e..a6651e3700 100644
--- a/app/widgets/gimppatternselect.c
+++ b/app/widgets/gimppatternselect.c
@@ -125,13 +125,13 @@ gimp_pattern_select_run_callback (GimpPdbDialog  *dialog,
                                         dialog->caller_context,
                                         NULL, error,
                                         dialog->callback_name,
-                                        G_TYPE_STRING,        gimp_object_get_name (object),
-                                        G_TYPE_INT,           gimp_temp_buf_get_width  (pattern->mask),
-                                        G_TYPE_INT,           gimp_temp_buf_get_height (pattern->mask),
-                                        G_TYPE_INT,           babl_format_get_bytes_per_pixel 
(gimp_temp_buf_get_format (pattern->mask)),
-                                        G_TYPE_INT,           array->length,
-                                        GIMP_TYPE_INT8_ARRAY, array,
-                                        G_TYPE_BOOLEAN,       closing,
+                                        G_TYPE_STRING,         gimp_object_get_name (object),
+                                        G_TYPE_INT,            gimp_temp_buf_get_width  (pattern->mask),
+                                        G_TYPE_INT,            gimp_temp_buf_get_height (pattern->mask),
+                                        G_TYPE_INT,            babl_format_get_bytes_per_pixel 
(gimp_temp_buf_get_format (pattern->mask)),
+                                        G_TYPE_INT,            array->length,
+                                        GIMP_TYPE_UINT8_ARRAY, array,
+                                        G_TYPE_BOOLEAN,        closing,
                                         G_TYPE_NONE);
 
   gimp_array_free (array);
diff --git a/devel-docs/libgimpbase/libgimpbase3-sections.txt 
b/devel-docs/libgimpbase/libgimpbase3-sections.txt
index 6168cc6f40..cb365f86e0 100644
--- a/devel-docs/libgimpbase/libgimpbase3-sections.txt
+++ b/devel-docs/libgimpbase/libgimpbase3-sections.txt
@@ -301,12 +301,12 @@ gimp_array_new
 gimp_array_copy
 gimp_array_free
 gimp_param_spec_array
-gimp_param_spec_int8_array
-gimp_value_get_int8_array
-gimp_value_dup_int8_array
-gimp_value_set_int8_array
-gimp_value_set_static_int8_array
-gimp_value_take_int8_array
+gimp_param_spec_uint8_array
+gimp_value_get_uint8_array
+gimp_value_dup_uint8_array
+gimp_value_set_uint8_array
+gimp_value_set_static_uint8_array
+gimp_value_take_uint8_array
 gimp_param_spec_int16_array
 gimp_value_get_int16_array
 gimp_value_dup_int16_array
@@ -345,7 +345,7 @@ GIMP_IS_PARAM_SPEC_ARRAY
 GIMP_IS_PARAM_SPEC_FLOAT_ARRAY
 GIMP_IS_PARAM_SPEC_INT16_ARRAY
 GIMP_IS_PARAM_SPEC_INT32_ARRAY
-GIMP_IS_PARAM_SPEC_INT8_ARRAY
+GIMP_IS_PARAM_SPEC_UINT8_ARRAY
 GIMP_IS_PARAM_SPEC_RGB_ARRAY
 GIMP_IS_PARAM_SPEC_STRING
 GIMP_IS_PARAM_SPEC_STRING_ARRAY
@@ -353,7 +353,7 @@ GIMP_PARAM_SPEC_ARRAY
 GIMP_PARAM_SPEC_FLOAT_ARRAY
 GIMP_PARAM_SPEC_INT16_ARRAY
 GIMP_PARAM_SPEC_INT32_ARRAY
-GIMP_PARAM_SPEC_INT8_ARRAY
+GIMP_PARAM_SPEC_UINT8_ARRAY
 GIMP_PARAM_SPEC_RGB_ARRAY
 GIMP_PARAM_SPEC_STRING
 GIMP_PARAM_SPEC_STRING_ARRAY
@@ -361,12 +361,12 @@ GIMP_TYPE_ARRAY
 GIMP_TYPE_FLOAT_ARRAY
 GIMP_TYPE_INT16_ARRAY
 GIMP_TYPE_INT32_ARRAY
-GIMP_TYPE_INT8_ARRAY
+GIMP_TYPE_UINT8_ARRAY
 GIMP_TYPE_PARAM_ARRAY
 GIMP_TYPE_PARAM_FLOAT_ARRAY
 GIMP_TYPE_PARAM_INT16_ARRAY
 GIMP_TYPE_PARAM_INT32_ARRAY
-GIMP_TYPE_PARAM_INT8_ARRAY
+GIMP_TYPE_PARAM_UINT8_ARRAY
 GIMP_TYPE_PARAM_RGB_ARRAY
 GIMP_TYPE_PARAM_STRING
 GIMP_TYPE_PARAM_STRING_ARRAY
@@ -376,7 +376,7 @@ GIMP_VALUE_HOLDS_ARRAY
 GIMP_VALUE_HOLDS_FLOAT_ARRAY
 GIMP_VALUE_HOLDS_INT16_ARRAY
 GIMP_VALUE_HOLDS_INT32_ARRAY
-GIMP_VALUE_HOLDS_INT8_ARRAY
+GIMP_VALUE_HOLDS_UINT8_ARRAY
 GIMP_VALUE_HOLDS_RGB_ARRAY
 GIMP_VALUE_HOLDS_STRING_ARRAY
 GimpArray
@@ -385,7 +385,7 @@ GimpParamSpecArray
 GimpParamSpecFloatArray
 GimpParamSpecInt16Array
 GimpParamSpecInt32Array
-GimpParamSpecInt8Array
+GimpParamSpecUInt8Array
 GimpParamSpecRGBArray
 GimpParamSpecString
 GimpParamSpecStringArray
@@ -393,12 +393,12 @@ gimp_array_get_type
 gimp_float_array_get_type
 gimp_int16_array_get_type
 gimp_int32_array_get_type
-gimp_int8_array_get_type
+gimp_uint8_array_get_type
 gimp_param_array_get_type
 gimp_param_float_array_get_type
 gimp_param_int16_array_get_type
 gimp_param_int32_array_get_type
-gimp_param_int8_array_get_type
+gimp_param_uint8_array_get_type
 gimp_param_rgb_array_get_type
 gimp_param_string_array_get_type
 gimp_param_string_get_type
diff --git a/devel-docs/libgimpbase/libgimpbase3.types b/devel-docs/libgimpbase/libgimpbase3.types
index b9a6fe365b..e09ebcaf06 100644
--- a/devel-docs/libgimpbase/libgimpbase3.types
+++ b/devel-docs/libgimpbase/libgimpbase3.types
@@ -2,14 +2,14 @@ gimp_array_get_type
 gimp_float_array_get_type
 gimp_int16_array_get_type
 gimp_int32_array_get_type
-gimp_int8_array_get_type
+gimp_uint8_array_get_type
 gimp_memsize_get_type
 gimp_metadata_get_type
 gimp_param_array_get_type
 gimp_param_float_array_get_type
 gimp_param_int16_array_get_type
 gimp_param_int32_array_get_type
-gimp_param_int8_array_get_type
+gimp_param_uint8_array_get_type
 gimp_param_rgb_array_get_type
 gimp_param_string_array_get_type
 gimp_param_string_get_type
diff --git a/libgimp/gimp.c b/libgimp/gimp.c
index fa9eca2d79..7a7c67e58e 100644
--- a/libgimp/gimp.c
+++ b/libgimp/gimp.c
@@ -452,7 +452,7 @@ _gimp_main_internal (GType                 plug_in_type,
       G_TYPE_STRING,           GIMP_TYPE_PARAM_STRING,
 
       GIMP_TYPE_ARRAY,         GIMP_TYPE_PARAM_ARRAY,
-      GIMP_TYPE_INT8_ARRAY,    GIMP_TYPE_PARAM_INT8_ARRAY,
+      GIMP_TYPE_UINT8_ARRAY,   GIMP_TYPE_PARAM_UINT8_ARRAY,
       GIMP_TYPE_INT16_ARRAY,   GIMP_TYPE_PARAM_INT16_ARRAY,
       GIMP_TYPE_INT32_ARRAY,   GIMP_TYPE_PARAM_INT32_ARRAY,
       GIMP_TYPE_FLOAT_ARRAY,   GIMP_TYPE_PARAM_FLOAT_ARRAY,
diff --git a/libgimp/gimpbrush_pdb.c b/libgimp/gimpbrush_pdb.c
index af67bd2954..5b5fb81980 100644
--- a/libgimp/gimpbrush_pdb.c
+++ b/libgimp/gimpbrush_pdb.c
@@ -414,10 +414,10 @@ gimp_brush_get_pixels (const gchar  *name,
       *height = g_value_get_int (gimp_value_array_index (return_vals, 2));
       *mask_bpp = g_value_get_int (gimp_value_array_index (return_vals, 3));
       *num_mask_bytes = g_value_get_int (gimp_value_array_index (return_vals, 4));
-      *mask_bytes = gimp_value_dup_int8_array (gimp_value_array_index (return_vals, 5));
+      *mask_bytes = gimp_value_dup_uint8_array (gimp_value_array_index (return_vals, 5));
       *color_bpp = g_value_get_int (gimp_value_array_index (return_vals, 6));
       *num_color_bytes = g_value_get_int (gimp_value_array_index (return_vals, 7));
-      *color_bytes = gimp_value_dup_int8_array (gimp_value_array_index (return_vals, 8));
+      *color_bytes = gimp_value_dup_uint8_array (gimp_value_array_index (return_vals, 8));
     }
 
   gimp_value_array_unref (return_vals);
diff --git a/libgimp/gimpbrushselect.c b/libgimp/gimpbrushselect.c
index 1fa241c5ef..7132a976e3 100644
--- a/libgimp/gimpbrushselect.c
+++ b/libgimp/gimpbrushselect.c
@@ -130,11 +130,11 @@ gimp_brush_select_new (const gchar          *title,
                                                  0, G_MAXINT, 0,
                                                  G_PARAM_READWRITE));
   gimp_procedure_add_argument (procedure,
-                               gimp_param_spec_int8_array ("mask-data",
-                                                           "Mask data",
-                                                           "The brush mask "
-                                                           "data",
-                                                           G_PARAM_READWRITE));
+                               gimp_param_spec_uint8_array ("mask-data",
+                                                            "Mask data",
+                                                            "The brush mask "
+                                                            "data",
+                                                            G_PARAM_READWRITE));
   gimp_procedure_add_argument (procedure,
                                g_param_spec_boolean ("closing",
                                                      "Closing",
@@ -210,7 +210,7 @@ gimp_temp_brush_run (GimpProcedure        *procedure,
   data->paint_mode      = g_value_get_enum   (gimp_value_array_index (args, 3));
   data->width           = g_value_get_int    (gimp_value_array_index (args, 4));
   data->height          = g_value_get_int    (gimp_value_array_index (args, 5));
-  data->brush_mask_data = gimp_value_dup_int8_array (gimp_value_array_index (args, 7));
+  data->brush_mask_data = gimp_value_dup_uint8_array (gimp_value_array_index (args, 7));
   data->closing         = g_value_get_boolean (gimp_value_array_index (args, 8));
 
   if (! data->idle_id)
diff --git a/libgimp/gimpdrawable_pdb.c b/libgimp/gimpdrawable_pdb.c
index 708082563a..98c1dfc01d 100644
--- a/libgimp/gimpdrawable_pdb.c
+++ b/libgimp/gimpdrawable_pdb.c
@@ -848,7 +848,7 @@ gimp_drawable_get_pixel (gint32  drawable_ID,
   if (g_value_get_enum (gimp_value_array_index (return_vals, 0)) == GIMP_PDB_SUCCESS)
     {
       *num_channels = g_value_get_int (gimp_value_array_index (return_vals, 1));
-      pixel = gimp_value_dup_int8_array (gimp_value_array_index (return_vals, 2));
+      pixel = gimp_value_dup_uint8_array (gimp_value_array_index (return_vals, 2));
     }
 
   gimp_value_array_unref (return_vals);
@@ -891,9 +891,9 @@ gimp_drawable_set_pixel (gint32        drawable_ID,
                                           G_TYPE_INT, x_coord,
                                           G_TYPE_INT, y_coord,
                                           G_TYPE_INT, num_channels,
-                                          GIMP_TYPE_INT8_ARRAY, NULL,
+                                          GIMP_TYPE_UINT8_ARRAY, NULL,
                                           G_TYPE_NONE);
-  gimp_value_set_int8_array (gimp_value_array_index (args, 4), pixel, num_channels);
+  gimp_value_set_uint8_array (gimp_value_array_index (args, 4), pixel, num_channels);
 
   if (pdb)
     return_vals = gimp_pdb_run_procedure_array (pdb,
@@ -1082,7 +1082,7 @@ _gimp_drawable_thumbnail (gint32   drawable_ID,
       *actual_height = g_value_get_int (gimp_value_array_index (return_vals, 2));
       *bpp = g_value_get_int (gimp_value_array_index (return_vals, 3));
       *thumbnail_data_count = g_value_get_int (gimp_value_array_index (return_vals, 4));
-      *thumbnail_data = gimp_value_dup_int8_array (gimp_value_array_index (return_vals, 5));
+      *thumbnail_data = gimp_value_dup_uint8_array (gimp_value_array_index (return_vals, 5));
     }
 
   gimp_value_array_unref (return_vals);
@@ -1168,7 +1168,7 @@ _gimp_drawable_sub_thumbnail (gint32   drawable_ID,
       *height = g_value_get_int (gimp_value_array_index (return_vals, 2));
       *bpp = g_value_get_int (gimp_value_array_index (return_vals, 3));
       *thumbnail_data_count = g_value_get_int (gimp_value_array_index (return_vals, 4));
-      *thumbnail_data = gimp_value_dup_int8_array (gimp_value_array_index (return_vals, 5));
+      *thumbnail_data = gimp_value_dup_uint8_array (gimp_value_array_index (return_vals, 5));
     }
 
   gimp_value_array_unref (return_vals);
diff --git a/libgimp/gimpgpcompat.c b/libgimp/gimpgpcompat.c
index e9196fa35d..5a842a1cd9 100644
--- a/libgimp/gimpgpcompat.c
+++ b/libgimp/gimpgpcompat.c
@@ -87,8 +87,8 @@ _gimp_gp_compat_param_spec (GimpPDBArgType  arg_type,
       break;
 
     case GIMP_PDB_INT8ARRAY:
-      pspec = gimp_param_spec_int8_array (name, nick, blurb,
-                                          G_PARAM_READWRITE);
+      pspec = gimp_param_spec_uint8_array (name, nick, blurb,
+                                           G_PARAM_READWRITE);
       break;
 
     case GIMP_PDB_FLOATARRAY:
@@ -210,7 +210,7 @@ _gimp_pdb_arg_type_to_gtype (GimpPDBArgType  type)
       return GIMP_TYPE_INT16_ARRAY;
 
     case GIMP_PDB_INT8ARRAY:
-      return GIMP_TYPE_INT8_ARRAY;
+      return GIMP_TYPE_UINT8_ARRAY;
 
     case GIMP_PDB_FLOATARRAY:
       return GIMP_TYPE_FLOAT_ARRAY;
@@ -293,7 +293,7 @@ _gimp_pdb_gtype_to_arg_type (GType type)
 
         { GIMP_TYPE_INT32_ARRAY,     GIMP_PDB_INT32ARRAY  },
         { GIMP_TYPE_INT16_ARRAY,     GIMP_PDB_INT16ARRAY  },
-        { GIMP_TYPE_INT8_ARRAY,      GIMP_PDB_INT8ARRAY   },
+        { GIMP_TYPE_UINT8_ARRAY,     GIMP_PDB_INT8ARRAY   },
         { GIMP_TYPE_FLOAT_ARRAY,     GIMP_PDB_FLOATARRAY  },
         { GIMP_TYPE_STRING_ARRAY,    GIMP_PDB_STRINGARRAY },
         { GIMP_TYPE_RGB_ARRAY,       GIMP_PDB_COLORARRAY  },
@@ -420,13 +420,13 @@ _gimp_params_to_value_array (const GimpParam  *params,
         case GIMP_PDB_INT8ARRAY:
           count = g_value_get_int (gimp_value_array_index (args, i - 1));
           if (full_copy)
-            gimp_value_set_int8_array (&value,
-                                       params[i].data.d_int8array,
-                                       count);
+            gimp_value_set_uint8_array (&value,
+                                        params[i].data.d_int8array,
+                                        count);
           else
-            gimp_value_set_static_int8_array (&value,
-                                              params[i].data.d_int8array,
-                                              count);
+            gimp_value_set_static_uint8_array (&value,
+                                               params[i].data.d_int8array,
+                                               count);
           break;
 
         case GIMP_PDB_FLOATARRAY:
@@ -597,9 +597,9 @@ _gimp_value_array_to_params (GimpValueArray *args,
 
         case GIMP_PDB_INT8ARRAY:
           if (full_copy)
-            params[i].data.d_int8array = gimp_value_dup_int8_array (value);
+            params[i].data.d_int8array = gimp_value_dup_uint8_array (value);
           else
-            params[i].data.d_int8array = (guint8 *) gimp_value_get_int8_array (value);
+            params[i].data.d_int8array = (guint8 *) gimp_value_get_uint8_array (value);
           break;
 
         case GIMP_PDB_FLOATARRAY:
diff --git a/libgimp/gimpgpparams-body.c b/libgimp/gimpgpparams-body.c
index 82796bf747..9edbdac9e2 100644
--- a/libgimp/gimpgpparams-body.c
+++ b/libgimp/gimpgpparams-body.c
@@ -254,18 +254,18 @@ _gimp_gp_param_to_value (gpointer        gimp,
                                            param->data.d_array.size /
                                            sizeof (gint16));
     }
-  else if (GIMP_VALUE_HOLDS_INT8_ARRAY (value))
+  else if (GIMP_VALUE_HOLDS_UINT8_ARRAY (value))
     {
       if (full_copy)
-        gimp_value_set_int8_array (value,
-                                   param->data.d_array.data,
-                                   param->data.d_array.size /
-                                   sizeof (guint8));
+        gimp_value_set_uint8_array (value,
+                                    param->data.d_array.data,
+                                    param->data.d_array.size /
+                                    sizeof (guint8));
       else
-        gimp_value_set_static_int8_array (value,
-                                          param->data.d_array.data,
-                                          param->data.d_array.size /
-                                          sizeof (guint8));
+        gimp_value_set_static_uint8_array (value,
+                                           param->data.d_array.data,
+                                           param->data.d_array.size /
+                                           sizeof (guint8));
     }
   else if (GIMP_VALUE_HOLDS_FLOAT_ARRAY (value))
     {
@@ -519,7 +519,7 @@ _gimp_value_to_gp_param (const GValue *value,
     }
   else if (GIMP_VALUE_HOLDS_INT32_ARRAY (value) ||
            GIMP_VALUE_HOLDS_INT16_ARRAY (value) ||
-           GIMP_VALUE_HOLDS_INT8_ARRAY  (value) ||
+           GIMP_VALUE_HOLDS_UINT8_ARRAY (value) ||
            GIMP_VALUE_HOLDS_FLOAT_ARRAY (value) ||
            GIMP_VALUE_HOLDS_RGB_ARRAY (value))
     {
diff --git a/libgimp/gimpgpparams.c b/libgimp/gimpgpparams.c
index 0fc60091f7..e740fce7fc 100644
--- a/libgimp/gimpgpparams.c
+++ b/libgimp/gimpgpparams.c
@@ -57,8 +57,8 @@ _gimp_gp_param_def_to_param_spec (gpointer          gimp,
       if (! strcmp (param_def->type_name, "GimpParamInt16Array"))
         return gimp_param_spec_int16_array (name, nick, blurb, flags);
 
-      if (! strcmp (param_def->type_name, "GimpParamInt8Array"))
-        return gimp_param_spec_int8_array (name, nick, blurb, flags);
+      if (! strcmp (param_def->type_name, "GimpParamUInt8Array"))
+        return gimp_param_spec_uint8_array (name, nick, blurb, flags);
 
       if (! strcmp (param_def->type_name, "GimpParamFloatArray"))
         return gimp_param_spec_float_array (name, nick, blurb, flags);
diff --git a/libgimp/gimpimage_pdb.c b/libgimp/gimpimage_pdb.c
index e990667db5..ad1b5a08bb 100644
--- a/libgimp/gimpimage_pdb.c
+++ b/libgimp/gimpimage_pdb.c
@@ -1974,7 +1974,7 @@ _gimp_image_get_colormap (gint32  image_ID,
   if (g_value_get_enum (gimp_value_array_index (return_vals, 0)) == GIMP_PDB_SUCCESS)
     {
       *num_bytes = g_value_get_int (gimp_value_array_index (return_vals, 1));
-      colormap = gimp_value_dup_int8_array (gimp_value_array_index (return_vals, 2));
+      colormap = gimp_value_dup_uint8_array (gimp_value_array_index (return_vals, 2));
     }
 
   gimp_value_array_unref (return_vals);
@@ -2011,9 +2011,9 @@ _gimp_image_set_colormap (gint32        image_ID,
   args = gimp_value_array_new_from_types (NULL,
                                           GIMP_TYPE_IMAGE_ID, image_ID,
                                           G_TYPE_INT, num_bytes,
-                                          GIMP_TYPE_INT8_ARRAY, NULL,
+                                          GIMP_TYPE_UINT8_ARRAY, NULL,
                                           G_TYPE_NONE);
-  gimp_value_set_int8_array (gimp_value_array_index (args, 2), colormap, num_bytes);
+  gimp_value_set_uint8_array (gimp_value_array_index (args, 2), colormap, num_bytes);
 
   if (pdb)
     return_vals = gimp_pdb_run_procedure_array (pdb,
@@ -2261,7 +2261,7 @@ _gimp_image_thumbnail (gint32   image_ID,
       *actual_height = g_value_get_int (gimp_value_array_index (return_vals, 2));
       *bpp = g_value_get_int (gimp_value_array_index (return_vals, 3));
       *thumbnail_data_count = g_value_get_int (gimp_value_array_index (return_vals, 4));
-      *thumbnail_data = gimp_value_dup_int8_array (gimp_value_array_index (return_vals, 5));
+      *thumbnail_data = gimp_value_dup_uint8_array (gimp_value_array_index (return_vals, 5));
     }
 
   gimp_value_array_unref (return_vals);
diff --git a/libgimp/gimpimagecolorprofile_pdb.c b/libgimp/gimpimagecolorprofile_pdb.c
index 3dbcb22b83..c5fed0d758 100644
--- a/libgimp/gimpimagecolorprofile_pdb.c
+++ b/libgimp/gimpimagecolorprofile_pdb.c
@@ -77,7 +77,7 @@ _gimp_image_get_color_profile (gint32  image_ID,
   if (g_value_get_enum (gimp_value_array_index (return_vals, 0)) == GIMP_PDB_SUCCESS)
     {
       *num_bytes = g_value_get_int (gimp_value_array_index (return_vals, 1));
-      profile_data = gimp_value_dup_int8_array (gimp_value_array_index (return_vals, 2));
+      profile_data = gimp_value_dup_uint8_array (gimp_value_array_index (return_vals, 2));
     }
 
   gimp_value_array_unref (return_vals);
@@ -131,7 +131,7 @@ _gimp_image_get_effective_color_profile (gint32  image_ID,
   if (g_value_get_enum (gimp_value_array_index (return_vals, 0)) == GIMP_PDB_SUCCESS)
     {
       *num_bytes = g_value_get_int (gimp_value_array_index (return_vals, 1));
-      profile_data = gimp_value_dup_int8_array (gimp_value_array_index (return_vals, 2));
+      profile_data = gimp_value_dup_uint8_array (gimp_value_array_index (return_vals, 2));
     }
 
   gimp_value_array_unref (return_vals);
@@ -170,9 +170,9 @@ _gimp_image_set_color_profile (gint32        image_ID,
   args = gimp_value_array_new_from_types (NULL,
                                           GIMP_TYPE_IMAGE_ID, image_ID,
                                           G_TYPE_INT, num_bytes,
-                                          GIMP_TYPE_INT8_ARRAY, NULL,
+                                          GIMP_TYPE_UINT8_ARRAY, NULL,
                                           G_TYPE_NONE);
-  gimp_value_set_int8_array (gimp_value_array_index (args, 2), color_profile, num_bytes);
+  gimp_value_set_uint8_array (gimp_value_array_index (args, 2), color_profile, num_bytes);
 
   if (pdb)
     return_vals = gimp_pdb_run_procedure_array (pdb,
@@ -272,11 +272,11 @@ _gimp_image_convert_color_profile (gint32                    image_ID,
   args = gimp_value_array_new_from_types (NULL,
                                           GIMP_TYPE_IMAGE_ID, image_ID,
                                           G_TYPE_INT, num_bytes,
-                                          GIMP_TYPE_INT8_ARRAY, NULL,
+                                          GIMP_TYPE_UINT8_ARRAY, NULL,
                                           GIMP_TYPE_COLOR_RENDERING_INTENT, intent,
                                           G_TYPE_BOOLEAN, bpc,
                                           G_TYPE_NONE);
-  gimp_value_set_int8_array (gimp_value_array_index (args, 2), color_profile, num_bytes);
+  gimp_value_set_uint8_array (gimp_value_array_index (args, 2), color_profile, num_bytes);
 
   if (pdb)
     return_vals = gimp_pdb_run_procedure_array (pdb,
diff --git a/libgimp/gimpimageconvert_pdb.c b/libgimp/gimpimageconvert_pdb.c
index 9b182cedbe..d87014d053 100644
--- a/libgimp/gimpimageconvert_pdb.c
+++ b/libgimp/gimpimageconvert_pdb.c
@@ -213,9 +213,9 @@ gimp_image_convert_set_dither_matrix (gint          width,
                                           G_TYPE_INT, width,
                                           G_TYPE_INT, height,
                                           G_TYPE_INT, matrix_length,
-                                          GIMP_TYPE_INT8_ARRAY, NULL,
+                                          GIMP_TYPE_UINT8_ARRAY, NULL,
                                           G_TYPE_NONE);
-  gimp_value_set_int8_array (gimp_value_array_index (args, 3), matrix, matrix_length);
+  gimp_value_set_uint8_array (gimp_value_array_index (args, 3), matrix, matrix_length);
 
   if (pdb)
     return_vals = gimp_pdb_run_procedure_array (pdb,
diff --git a/libgimp/gimppattern_pdb.c b/libgimp/gimppattern_pdb.c
index cee2c5ae3a..56f22e7208 100644
--- a/libgimp/gimppattern_pdb.c
+++ b/libgimp/gimppattern_pdb.c
@@ -151,7 +151,7 @@ gimp_pattern_get_pixels (const gchar  *name,
       *height = g_value_get_int (gimp_value_array_index (return_vals, 2));
       *bpp = g_value_get_int (gimp_value_array_index (return_vals, 3));
       *num_color_bytes = g_value_get_int (gimp_value_array_index (return_vals, 4));
-      *color_bytes = gimp_value_dup_int8_array (gimp_value_array_index (return_vals, 5));
+      *color_bytes = gimp_value_dup_uint8_array (gimp_value_array_index (return_vals, 5));
     }
 
   gimp_value_array_unref (return_vals);
diff --git a/libgimp/gimppatternselect.c b/libgimp/gimppatternselect.c
index 7217638d48..8b5437248e 100644
--- a/libgimp/gimppatternselect.c
+++ b/libgimp/gimppatternselect.c
@@ -112,11 +112,11 @@ gimp_pattern_select_new (const gchar            *title,
                                                  0, G_MAXINT, 0,
                                                  G_PARAM_READWRITE));
   gimp_procedure_add_argument (procedure,
-                               gimp_param_spec_int8_array ("mask-data",
-                                                           "Mask data",
-                                                           "The pattern mask "
-                                                           "data",
-                                                           G_PARAM_READWRITE));
+                               gimp_param_spec_uint8_array ("mask-data",
+                                                            "Mask data",
+                                                            "The pattern mask "
+                                                            "data",
+                                                            G_PARAM_READWRITE));
   gimp_procedure_add_argument (procedure,
                                g_param_spec_boolean ("closing",
                                                      "Closing",
@@ -189,7 +189,7 @@ gimp_temp_pattern_run (GimpProcedure        *procedure,
   data->width             = g_value_get_int    (gimp_value_array_index (args, 1));
   data->height            = g_value_get_int    (gimp_value_array_index (args, 2));
   data->bytes             = g_value_get_int    (gimp_value_array_index (args, 3));
-  data->pattern_mask_data = gimp_value_dup_int8_array (gimp_value_array_index (args, 5));
+  data->pattern_mask_data = gimp_value_dup_uint8_array (gimp_value_array_index (args, 5));
   data->closing           = g_value_get_boolean (gimp_value_array_index (args, 6));
 
   if (! data->idle_id)
diff --git a/libgimp/gimppdb_pdb.c b/libgimp/gimppdb_pdb.c
index 0e122b3d15..3e3dbe0df4 100644
--- a/libgimp/gimppdb_pdb.c
+++ b/libgimp/gimppdb_pdb.c
@@ -447,7 +447,7 @@ _gimp_pdb_get_data (const gchar  *identifier,
   if (success)
     {
       *bytes = g_value_get_int (gimp_value_array_index (return_vals, 1));
-      *data = gimp_value_dup_int8_array (gimp_value_array_index (return_vals, 2));
+      *data = gimp_value_dup_uint8_array (gimp_value_array_index (return_vals, 2));
     }
 
   gimp_value_array_unref (return_vals);
@@ -523,9 +523,9 @@ _gimp_pdb_set_data (const gchar  *identifier,
   args = gimp_value_array_new_from_types (NULL,
                                           G_TYPE_STRING, identifier,
                                           G_TYPE_INT, bytes,
-                                          GIMP_TYPE_INT8_ARRAY, NULL,
+                                          GIMP_TYPE_UINT8_ARRAY, NULL,
                                           G_TYPE_NONE);
-  gimp_value_set_int8_array (gimp_value_array_index (args, 2), data, bytes);
+  gimp_value_set_uint8_array (gimp_value_array_index (args, 2), data, bytes);
 
   if (pdb)
     return_vals = gimp_pdb_run_procedure_array (pdb,
diff --git a/libgimp/gimpplugin_pdb.c b/libgimp/gimpplugin_pdb.c
index 769a5a7ae9..c40f7713b9 100644
--- a/libgimp/gimpplugin_pdb.c
+++ b/libgimp/gimpplugin_pdb.c
@@ -238,9 +238,9 @@ _gimp_plugin_icon_register (const gchar  *procedure_name,
                                           G_TYPE_STRING, procedure_name,
                                           GIMP_TYPE_ICON_TYPE, icon_type,
                                           G_TYPE_INT, icon_data_length,
-                                          GIMP_TYPE_INT8_ARRAY, NULL,
+                                          GIMP_TYPE_UINT8_ARRAY, NULL,
                                           G_TYPE_NONE);
-  gimp_value_set_int8_array (gimp_value_array_index (args, 3), icon_data, icon_data_length);
+  gimp_value_set_uint8_array (gimp_value_array_index (args, 3), icon_data, icon_data_length);
 
   if (pdb)
     return_vals = gimp_pdb_run_procedure_array (pdb,
diff --git a/libgimpbase/gimpbase.def b/libgimpbase/gimpbase.def
index 90d1bf8e5a..c3baf024b5 100644
--- a/libgimpbase/gimpbase.def
+++ b/libgimpbase/gimpbase.def
@@ -68,8 +68,6 @@ EXPORTS
        gimp_installation_directory_file
        gimp_int16_array_get_type
        gimp_int32_array_get_type
-       gimp_int8_array_get_type
-       gimp_int8_get_type
        gimp_interpolation_type_get_type
        gimp_is_canonical_identifier
        gimp_join_style_get_type
@@ -110,7 +108,6 @@ EXPORTS
        gimp_param_float_array_get_type
        gimp_param_int16_array_get_type
        gimp_param_int32_array_get_type
-       gimp_param_int8_array_get_type
        gimp_param_memsize_get_type
        gimp_param_parasite_get_type
        gimp_param_rgb_array_get_type
@@ -118,16 +115,17 @@ EXPORTS
        gimp_param_spec_float_array
        gimp_param_spec_int16_array
        gimp_param_spec_int32_array
-       gimp_param_spec_int8_array
        gimp_param_spec_memsize
        gimp_param_spec_parasite
        gimp_param_spec_rgb_array
        gimp_param_spec_string
        gimp_param_spec_string_array
+       gimp_param_spec_uint8_array
        gimp_param_spec_unit
        gimp_param_spec_value_array
        gimp_param_string_array_get_type
        gimp_param_string_get_type
+       gimp_param_uint8_array_get_type
        gimp_param_unit_get_type
        gimp_param_value_array_get_type
        gimp_parasite_compare
@@ -193,6 +191,8 @@ EXPORTS
        gimp_type_get_translation_domain
        gimp_type_set_translation_context
        gimp_type_set_translation_domain
+       gimp_uint8_array_get_type
+       gimp_uint8_get_type
        gimp_unit_format_string
        gimp_unit_get_abbreviation
        gimp_unit_get_deletion_flag
@@ -228,33 +228,33 @@ EXPORTS
        gimp_value_dup_float_array
        gimp_value_dup_int16_array
        gimp_value_dup_int32_array
-       gimp_value_dup_int8_array
        gimp_value_dup_rgb_array
        gimp_value_dup_string_array
+       gimp_value_dup_uint8_array
        gimp_value_get_float_array
        gimp_value_get_int16_array
        gimp_value_get_int32_array
-       gimp_value_get_int8_array
        gimp_value_get_rgb_array
        gimp_value_get_string_array
+       gimp_value_get_uint8_array
        gimp_value_set_float_array
        gimp_value_set_int16_array
        gimp_value_set_int32_array
-       gimp_value_set_int8_array
        gimp_value_set_rgb_array
        gimp_value_set_static_float_array
        gimp_value_set_static_int16_array
        gimp_value_set_static_int32_array
-       gimp_value_set_static_int8_array
        gimp_value_set_static_rgb_array
        gimp_value_set_static_string_array
+       gimp_value_set_static_uint8_array
        gimp_value_set_string_array
+       gimp_value_set_uint8_array
        gimp_value_take_float_array
        gimp_value_take_int16_array
        gimp_value_take_int32_array
-       gimp_value_take_int8_array
        gimp_value_take_rgb_array
        gimp_value_take_string_array
+       gimp_value_take_uint8_array
        gimp_vectors_stroke_type_get_type
        gimp_wire_clear_error
        gimp_wire_destroy
diff --git a/libgimpbase/gimpparamspecs.h b/libgimpbase/gimpparamspecs.h
index e481e33227..689b1cf72e 100644
--- a/libgimpbase/gimpparamspecs.h
+++ b/libgimpbase/gimpparamspecs.h
@@ -153,48 +153,48 @@ GParamSpec * gimp_param_spec_array     (const gchar  *name,
 
 
 /*
- * GIMP_TYPE_INT8_ARRAY
+ * GIMP_TYPE_UINT8_ARRAY
  */
 
-#define GIMP_TYPE_INT8_ARRAY               (gimp_int8_array_get_type ())
-#define GIMP_VALUE_HOLDS_INT8_ARRAY(value) (G_TYPE_CHECK_VALUE_TYPE ((value), GIMP_TYPE_INT8_ARRAY))
+#define GIMP_TYPE_UINT8_ARRAY               (gimp_uint8_array_get_type ())
+#define GIMP_VALUE_HOLDS_UINT8_ARRAY(value) (G_TYPE_CHECK_VALUE_TYPE ((value), GIMP_TYPE_UINT8_ARRAY))
 
-GType   gimp_int8_array_get_type           (void) G_GNUC_CONST;
+GType   gimp_uint8_array_get_type           (void) G_GNUC_CONST;
 
 
 /*
- * GIMP_TYPE_PARAM_INT8_ARRAY
+ * GIMP_TYPE_PARAM_UINT8_ARRAY
  */
 
-#define GIMP_TYPE_PARAM_INT8_ARRAY           (gimp_param_int8_array_get_type ())
-#define GIMP_PARAM_SPEC_INT8_ARRAY(pspec)    (G_TYPE_CHECK_INSTANCE_CAST ((pspec), 
GIMP_TYPE_PARAM_INT8_ARRAY, GimpParamSpecInt8Array))
-#define GIMP_IS_PARAM_SPEC_INT8_ARRAY(pspec) (G_TYPE_CHECK_INSTANCE_TYPE ((pspec), 
GIMP_TYPE_PARAM_INT8_ARRAY))
+#define GIMP_TYPE_PARAM_UINT8_ARRAY           (gimp_param_uint8_array_get_type ())
+#define GIMP_PARAM_SPEC_UINT8_ARRAY(pspec)    (G_TYPE_CHECK_INSTANCE_CAST ((pspec), 
GIMP_TYPE_PARAM_UINT8_ARRAY, GimpParamSpecUInt8Array))
+#define GIMP_IS_PARAM_SPEC_UINT8_ARRAY(pspec) (G_TYPE_CHECK_INSTANCE_TYPE ((pspec), 
GIMP_TYPE_PARAM_UINT8_ARRAY))
 
-typedef struct _GimpParamSpecInt8Array GimpParamSpecInt8Array;
+typedef struct _GimpParamSpecUInt8Array GimpParamSpecUInt8Array;
 
-struct _GimpParamSpecInt8Array
+struct _GimpParamSpecUInt8Array
 {
   GimpParamSpecArray parent_instance;
 };
 
-GType          gimp_param_int8_array_get_type   (void) G_GNUC_CONST;
-
-GParamSpec   * gimp_param_spec_int8_array       (const gchar  *name,
-                                                 const gchar  *nick,
-                                                 const gchar  *blurb,
-                                                 GParamFlags   flags);
-
-const guint8 * gimp_value_get_int8_array        (const GValue *value);
-guint8       * gimp_value_dup_int8_array        (const GValue *value);
-void           gimp_value_set_int8_array        (GValue       *value,
-                                                 const guint8 *array,
-                                                 gsize         length);
-void           gimp_value_set_static_int8_array (GValue       *value,
-                                                 const guint8 *array,
-                                                 gsize         length);
-void           gimp_value_take_int8_array       (GValue       *value,
-                                                 guint8       *array,
-                                                 gsize         length);
+GType          gimp_param_uint8_array_get_type   (void) G_GNUC_CONST;
+
+GParamSpec   * gimp_param_spec_uint8_array       (const gchar  *name,
+                                                  const gchar  *nick,
+                                                  const gchar  *blurb,
+                                                  GParamFlags   flags);
+
+const guint8 * gimp_value_get_uint8_array        (const GValue *value);
+guint8       * gimp_value_dup_uint8_array        (const GValue *value);
+void           gimp_value_set_uint8_array        (GValue       *value,
+                                                  const guint8 *array,
+                                                  gsize         length);
+void           gimp_value_set_static_uint8_array (GValue       *value,
+                                                  const guint8 *array,
+                                                  gsize         length);
+void           gimp_value_take_uint8_array       (GValue       *value,
+                                                  guint8       *array,
+                                                  gsize         length);
 
 
 /*
diff --git a/pdb/app.pl b/pdb/app.pl
index b3e6829f95..ca236ba43a 100644
--- a/pdb/app.pl
+++ b/pdb/app.pl
@@ -537,10 +537,10 @@ CODE
     }
     elsif ($pdbtype eq 'int8array') {
        $pspec = <<CODE;
-gimp_param_spec_int8_array ("$name",
-                            "$nick",
-                            "$blurb",
-                            $flags)
+gimp_param_spec_uint8_array ("$name",
+                             "$nick",
+                             "$blurb",
+                             $flags)
 CODE
     }
     elsif ($pdbtype eq 'floatarray') {
diff --git a/pdb/pdb.pl b/pdb/pdb.pl
index 39b8d0c656..abd6287156 100644
--- a/pdb/pdb.pl
+++ b/pdb/pdb.pl
@@ -95,17 +95,17 @@ package Gimp::CodeGen::pdb;
                     take_value_func => 'gimp_value_take_int16_array ($value, $var, $var_len)' },
 
     int8array   => { name            => 'INT8ARRAY',
-                    gtype           => 'GIMP_TYPE_INT8_ARRAY',
+                    gtype           => 'GIMP_TYPE_UINT8_ARRAY',
                     type            => 'guint8 *',
                     const_type      => 'const guint8 *',
                     array           => 1,
                     init_value      => 'NULL',
                     in_annotate     => '(element-type guint8)',
                     out_annotate    => '(element-type guint8) (transfer full)',
-                    get_value_func  => '$var = gimp_value_get_int8_array ($value)',
-                    dup_value_func  => '$var = gimp_value_dup_int8_array ($value)',
-                    set_value_func  => 'gimp_value_set_int8_array ($value, $var, $var_len)',
-                    take_value_func => 'gimp_value_take_int8_array ($value, $var, $var_len)' },
+                    get_value_func  => '$var = gimp_value_get_uint8_array ($value)',
+                    dup_value_func  => '$var = gimp_value_dup_uint8_array ($value)',
+                    set_value_func  => 'gimp_value_set_uint8_array ($value, $var, $var_len)',
+                    take_value_func => 'gimp_value_take_uint8_array ($value, $var, $var_len)' },
 
     floatarray  => { name            => 'FLOATARRAY',
                     gtype           => 'GIMP_TYPE_FLOAT_ARRAY',
diff --git a/plug-ins/common/colormap-remap.c b/plug-ins/common/colormap-remap.c
index 1d2cb57389..4c18f2bdb9 100644
--- a/plug-ins/common/colormap-remap.c
+++ b/plug-ins/common/colormap-remap.c
@@ -166,11 +166,11 @@ remap_create_procedure (GimpPlugIn  *plug_in,
                                                      1, 256, 1,
                                                      G_PARAM_READWRITE));
       gimp_procedure_add_argument (procedure,
-                                   gimp_param_spec_int8_array ("map",
-                                                               "Map",
-                                                               "Remap array "
-                                                               "for the colormap",
-                                                               G_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("map",
+                                                                "Map",
+                                                                "Remap array "
+                                                                "for the colormap",
+                                                                G_PARAM_READWRITE));
     }
   else if (! strcmp (name, PLUG_IN_PROC_SWAP))
     {
@@ -268,8 +268,8 @@ remap_run (GimpProcedure        *procedure,
 
       g_free (gimp_image_get_colormap (image_ID, &n_cols));
 
-      n_col_args = g_value_get_int           (gimp_value_array_index (args, 3));
-      col_args   = gimp_value_get_int8_array (gimp_value_array_index (args, 4));
+      n_col_args = g_value_get_int            (gimp_value_array_index (args, 3));
+      col_args   = gimp_value_get_uint8_array (gimp_value_array_index (args, 4));
 
       switch (run_mode)
         {
diff --git a/plug-ins/common/file-gih.c b/plug-ins/common/file-gih.c
index 3e6f5ba00d..72233a03e4 100644
--- a/plug-ins/common/file-gih.c
+++ b/plug-ins/common/file-gih.c
@@ -246,11 +246,11 @@ gih_create_procedure (GimpPlugIn  *plug_in,
                                                      1, 4, 1,
                                                      GIMP_PARAM_READWRITE));
       gimp_procedure_add_argument (procedure,
-                                   gimp_param_spec_int8_array ("rank",
-                                                               "Rank",
-                                                               "Ranks of the "
-                                                               "dimensions",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_uint8_array ("rank",
+                                                                "Rank",
+                                                                "Ranks of the "
+                                                                "dimensions",
+                                                                GIMP_PARAM_READWRITE));
       gimp_procedure_add_argument (procedure,
                                    g_param_spec_int ("dimension",
                                                      "Dimension",
@@ -259,10 +259,10 @@ gih_create_procedure (GimpPlugIn  *plug_in,
                                                      1, 4, 1,
                                                      GIMP_PARAM_READWRITE));
       gimp_procedure_add_argument (procedure,
-                                   gimp_param_spec_int8_array ("sel",
-                                                               "Sel",
-                                                               "Selection modes",
-                                                               GIMP_PARAM_READWRITE));
+                                   gimp_param_spec_string_array ("sel",
+                                                                 "Sel",
+                                                                 "Selection modes",
+                                                                 GIMP_PARAM_READWRITE));
     }
 
   return procedure;
@@ -399,7 +399,7 @@ gih_save (GimpProcedure        *procedure,
       else
         {
           const guint8 *rank =
-            gimp_value_get_int8_array (gimp_value_array_index (args, 7));
+            gimp_value_get_uint8_array (gimp_value_array_index (args, 7));
 
           const gchar **sel =
             gimp_value_get_string_array (gimp_value_array_index (args, 9));
diff --git a/plug-ins/script-fu/scheme-wrapper.c b/plug-ins/script-fu/scheme-wrapper.c
index f57471a452..71b808ed32 100644
--- a/plug-ins/script-fu/scheme-wrapper.c
+++ b/plug-ins/script-fu/scheme-wrapper.c
@@ -829,7 +829,7 @@ script_fu_marshal_procedure_call (scheme   *sc,
 #endif
             }
         }
-      else if (GIMP_VALUE_HOLDS_INT8_ARRAY (&value))
+      else if (GIMP_VALUE_HOLDS_UINT8_ARRAY (&value))
         {
           vector = sc->vptr->pair_car (a);
           if (! sc->vptr->is_vector (vector))
@@ -870,7 +870,7 @@ script_fu_marshal_procedure_call (scheme   *sc,
                   array[j] = (guint8) sc->vptr->ivalue (v_element);
                 }
 
-              gimp_value_take_int8_array (&value, array, n_elements);
+              gimp_value_take_uint8_array (&value, array, n_elements);
 
 #if DEBUG_MARSHALL
               {
@@ -1406,11 +1406,11 @@ script_fu_marshal_procedure_call (scheme   *sc,
 
               return_val = sc->vptr->cons (sc, vector, return_val);
             }
-          else if (GIMP_VALUE_HOLDS_INT8_ARRAY (value))
+          else if (GIMP_VALUE_HOLDS_UINT8_ARRAY (value))
             {
               gint32        n      = g_value_get_int
                                        (gimp_value_array_index (values, i));
-              const guint8 *v      = gimp_value_get_int8_array (value);
+              const guint8 *v      = gimp_value_get_uint8_array (value);
               pointer       vector = sc->vptr->mk_vector (sc, n);
 
               for (j = 0; j < n; j++)


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libgimpbase/gimpparamspecs.c b/libgimpbase/gimpparamspecs.c
index 917d71c177..93f92c5dd5 100644
--- a/libgimpbase/gimpparamspecs.c
+++ b/libgimpbase/gimpparamspecs.c
@@ -428,16 +428,16 @@ gimp_value_take_array (GValue *value,
 
 
 /*
- * GIMP_TYPE_INT8_ARRAY
+ * GIMP_TYPE_UINT8_ARRAY
  */
 
 GType
-gimp_int8_array_get_type (void)
+gimp_uint8_array_get_type (void)
 {
   static GType type = 0;
 
   if (! type)
-    type = g_boxed_type_register_static ("GimpInt8Array",
+    type = g_boxed_type_register_static ("GimpUInt8Array",
                                          (GBoxedCopyFunc) gimp_array_copy,
                                          (GBoxedFreeFunc) gimp_array_free);
 
@@ -446,14 +446,14 @@ gimp_int8_array_get_type (void)
 
 
 /*
- * GIMP_TYPE_PARAM_INT8_ARRAY
+ * GIMP_TYPE_PARAM_UINT8_ARRAY
  */
 
-static void   gimp_param_int8_array_class_init (GParamSpecClass *klass);
-static void   gimp_param_int8_array_init       (GParamSpec      *pspec);
+static void   gimp_param_uint8_array_class_init (GParamSpecClass *klass);
+static void   gimp_param_uint8_array_init       (GParamSpec      *pspec);
 
 GType
-gimp_param_int8_array_get_type (void)
+gimp_param_uint8_array_get_type (void)
 {
   static GType type = 0;
 
@@ -463,103 +463,103 @@ gimp_param_int8_array_get_type (void)
       {
         sizeof (GParamSpecClass),
         NULL, NULL,
-        (GClassInitFunc) gimp_param_int8_array_class_init,
+        (GClassInitFunc) gimp_param_uint8_array_class_init,
         NULL, NULL,
         sizeof (GimpParamSpecArray),
         0,
-        (GInstanceInitFunc) gimp_param_int8_array_init
+        (GInstanceInitFunc) gimp_param_uint8_array_init
       };
 
       type = g_type_register_static (GIMP_TYPE_PARAM_ARRAY,
-                                     "GimpParamInt8Array", &info, 0);
+                                     "GimpParamUInt8Array", &info, 0);
     }
 
   return type;
 }
 
 static void
-gimp_param_int8_array_class_init (GParamSpecClass *klass)
+gimp_param_uint8_array_class_init (GParamSpecClass *klass)
 {
-  klass->value_type = GIMP_TYPE_INT8_ARRAY;
+  klass->value_type = GIMP_TYPE_UINT8_ARRAY;
 }
 
 static void
-gimp_param_int8_array_init (GParamSpec *pspec)
+gimp_param_uint8_array_init (GParamSpec *pspec)
 {
 }
 
 /**
- * gimp_param_spec_int8_array:
+ * gimp_param_spec_uint8_array:
  * @name:  Canonical name of the property specified.
  * @nick:  Nick name of the property specified.
  * @blurb: Description of the property specified.
  * @flags: Flags for the property specified.
  *
  * Creates a new #GimpParamSpecInt8Array specifying a
  * #GIMP_TYPE_INT8_ARRAY property.
  *
  * See g_param_spec_internal() for details on property names.
  *
  * Returns: (transfer full): The newly created #GimpParamSpecInt8Array.
  *
  * Since: 3.0
  **/
 GParamSpec *
-gimp_param_spec_int8_array (const gchar *name,
-                            const gchar *nick,
-                            const gchar *blurb,
-                            GParamFlags  flags)
+gimp_param_spec_uint8_array (const gchar *name,
+                             const gchar *nick,
+                             const gchar *blurb,
+                             GParamFlags  flags)
 {
   GimpParamSpecArray *array_spec;
 
-  array_spec = g_param_spec_internal (GIMP_TYPE_PARAM_INT8_ARRAY,
+  array_spec = g_param_spec_internal (GIMP_TYPE_PARAM_UINT8_ARRAY,
                                       name, nick, blurb, flags);
 
   return G_PARAM_SPEC (array_spec);
 }
 
 const guint8 *
-gimp_value_get_int8_array (const GValue *value)
+gimp_value_get_uint8_array (const GValue *value)
 {
-  g_return_val_if_fail (GIMP_VALUE_HOLDS_INT8_ARRAY (value), NULL);
+  g_return_val_if_fail (GIMP_VALUE_HOLDS_UINT8_ARRAY (value), NULL);
 
   return gimp_value_get_array (value);
 }
 
 guint8 *
-gimp_value_dup_int8_array (const GValue *value)
+gimp_value_dup_uint8_array (const GValue *value)
 {
-  g_return_val_if_fail (GIMP_VALUE_HOLDS_INT8_ARRAY (value), NULL);
+  g_return_val_if_fail (GIMP_VALUE_HOLDS_UINT8_ARRAY (value), NULL);
 
   return gimp_value_dup_array (value);
 }
 
 void
-gimp_value_set_int8_array (GValue       *value,
-                           const guint8 *data,
-                           gsize         length)
+gimp_value_set_uint8_array (GValue       *value,
+                            const guint8 *data,
+                            gsize         length)
 {
-  g_return_if_fail (GIMP_VALUE_HOLDS_INT8_ARRAY (value));
+  g_return_if_fail (GIMP_VALUE_HOLDS_UINT8_ARRAY (value));
 
   gimp_value_set_array (value, data, length);
 }
 
 void
-gimp_value_set_static_int8_array (GValue       *value,
-                                  const guint8 *data,
-                                  gsize         length)
+gimp_value_set_static_uint8_array (GValue       *value,
+                                   const guint8 *data,
+                                   gsize         length)
 {
-  g_return_if_fail (GIMP_VALUE_HOLDS_INT8_ARRAY (value));
+  g_return_if_fail (GIMP_VALUE_HOLDS_UINT8_ARRAY (value));
 
   gimp_value_set_static_array (value, data, length);
 }
 
 void
-gimp_value_take_int8_array (GValue *value,
-                            guint8 *data,
-                            gsize   length)
+gimp_value_take_uint8_array (GValue *value,
+                             guint8 *data,
+                             gsize   length)
 {
-  g_return_if_fail (GIMP_VALUE_HOLDS_INT8_ARRAY (value));
+  g_return_if_fail (GIMP_VALUE_HOLDS_UINT8_ARRAY (value));
 
   gimp_value_take_array (value, data, length);
 }
@@ -463,103 +463,103 @@ gimp_param_int8_array_get_type (void)
  * @flags: Flags for the property specified.
  *
- * Creates a new #GimpParamSpecInt8Array specifying a
- * #GIMP_TYPE_INT8_ARRAY property.
+ * Creates a new #GimpParamSpecUInt8Array specifying a
+ * #GIMP_TYPE_UINT8_ARRAY property.
  *
  * See g_param_spec_internal() for details on property names.
@@ -463,103 +463,103 @@ gimp_param_int8_array_get_type (void)
  * See g_param_spec_internal() for details on property names.
  *
- * Returns: (transfer full): The newly created #GimpParamSpecInt8Array.
+ * Returns: (transfer full): The newly created #GimpParamSpecUInt8Array.
  *
  * Since: 3.0